# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 4.5.7 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCommentAddCommentsResponseInner(BaseModel):
    """
    comment
    """ # noqa: E501
    avatar: Optional[StrictStr] = Field(description="HTML user picture")
    content: Optional[StrictStr] = Field(description="The content text formatted")
    delete: Optional[StrictBool] = Field(default=None, description="Permission to delete=true/false")
    format: Optional[StrictInt] = Field(description="content format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    fullname: Optional[StrictStr] = Field(description="fullname")
    id: Optional[StrictInt] = Field(description="Comment ID")
    profileurl: Optional[StrictStr] = Field(description="URL profile")
    strftimeformat: Optional[StrictStr] = Field(description="Time format")
    time: Optional[StrictStr] = Field(description="Time in human format")
    timecreated: Optional[StrictInt] = Field(description="Time created (timestamp)")
    userid: Optional[StrictInt] = Field(description="User ID")
    __properties: ClassVar[List[str]] = ["avatar", "content", "delete", "format", "fullname", "id", "profileurl", "strftimeformat", "time", "timecreated", "userid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCommentAddCommentsResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if delete (nullable) is None
        # and model_fields_set contains the field
        if self.delete is None and "delete" in self.model_fields_set:
            _dict['delete'] = None

        # set to None if format (nullable) is None
        # and model_fields_set contains the field
        if self.format is None and "format" in self.model_fields_set:
            _dict['format'] = None

        # set to None if fullname (nullable) is None
        # and model_fields_set contains the field
        if self.fullname is None and "fullname" in self.model_fields_set:
            _dict['fullname'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if profileurl (nullable) is None
        # and model_fields_set contains the field
        if self.profileurl is None and "profileurl" in self.model_fields_set:
            _dict['profileurl'] = None

        # set to None if strftimeformat (nullable) is None
        # and model_fields_set contains the field
        if self.strftimeformat is None and "strftimeformat" in self.model_fields_set:
            _dict['strftimeformat'] = None

        # set to None if time (nullable) is None
        # and model_fields_set contains the field
        if self.time is None and "time" in self.model_fields_set:
            _dict['time'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCommentAddCommentsResponseInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCommentAddCommentsResponseInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "avatar": obj.get("avatar"),
            "content": obj.get("content"),
            "delete": obj.get("delete"),
            "format": obj.get("format"),
            "fullname": obj.get("fullname"),
            "id": obj.get("id"),
            "profileurl": obj.get("profileurl"),
            "strftimeformat": obj.get("strftimeformat"),
            "time": obj.get("time"),
            "timecreated": obj.get("timecreated"),
            "userid": obj.get("userid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


